@@ -5,7 +5,7 @@
 #' 'xportr.character_types' option is used to explicitly collapse the class of a
 #' column to character using `as.character`. Similarly, 'xportr.numeric_types'
 #' will collapse a column to a numeric type. If no type is passed for a
-#' variable and it isn't identifed as a timing variable, it is assumed to be numeric and coerced with `as.numeric`.
+#' variable, it is assumed to be numeric and coerced with `as.numeric()`.
 #'
 #' Certain care should be taken when using timing variables. R serializes dates
 #' based on a reference date of 01/01/1970 where XPT uses 01/01/1960. This can
@@ -13,10 +13,6 @@
 #' using a date class. For this reason, `xportr` will try to determine what
 #' should happen with variables that appear to be used to denote time.
 #'
-#' For variables that end in DT, DTM, or, TM, if they are not explicitly noted
-#' in 'xportr.numeric_types' or 'xportr.character_types', they are coerced to
-#' numeric results.
-#'
 #' @inheritParams xportr_length
 #'
 #' @section Messaging: `type_log()` is the primary messaging tool for
@@ -36,24 +32,20 @@
 #'   "dataset". This is the column subset by the 'domain' argument in the
 #'   function.
 #'
-#'   2) Format Name - passed as the 'xportr.format_name' option. Default:
-#'   "format". Character values to update the 'format.sas' attribute of the
-#'   column. This is passed to `haven::write` to note the format.
-#'
-#'   3) Variable Name - passed as the 'xportr.variable_name' option. Default:
+#'   2) Variable Name - passed as the 'xportr.variable_name' option. Default:
 #'   "variable". This is used to match columns in '.df' argument and the
 #'   metadata.
 #'
-#'   4) Variable Type - passed as the 'xportr.type_name'. Default: "type". This
+#'   3) Variable Type - passed as the 'xportr.type_name'. Default: "type". This
 #'   is used to note the XPT variable "type" options are numeric or character.
 #'
-#'   5) (Option only) Character Types - The list of classes that should be
+#'   4) (Option only) Character Types - The list of classes that should be
 #'   explicitly coerced to a XPT Character type. Default: c( "character",
 #'   "char", "text", "date", "posixct", "posixt", "datetime", "time",
 #'   "partialdate", "partialtime", "partialdatetime", "incompletedatetime",
-#'   "durationdatetime", "intervaldatetime")
+#'   "durationdatetime", "intervaldatetime")`
 #'
-#'   6) (Option only) Numeric Types - The list of classes that should be
+#'   5) (Option only) Numeric Types - The list of classes that should be
 #'   explicitly coerced to a XPT numeric type. Default: c("integer", "numeric",
 #'   "num", "float")
 #'
@@ -64,8 +56,7 @@
 #' metadata <- data.frame(
 #'   dataset = "test",
 #'   variable = c("Subj", "Param", "Val", "NotUsed"),
-#'   type = c("numeric", "character", "numeric", "character"),
-#'   format = NA
+#'   type = c("numeric", "character", "numeric", "character")
 #' )
 #'
 #' .df <- data.frame(
@@ -79,48 +70,54 @@
 xportr_type <- function(.df,
                         metadata = NULL,
                         domain = NULL,
-                        verbose = getOption("xportr.type_verbose", "none"),
+                        verbose = NULL,
                         metacore = deprecated()) {
   if (!missing(metacore)) {
-    lifecycle::deprecate_warn(
-      when = "0.3.0",
+    lifecycle::deprecate_stop(
+      when = "0.3.1.9005",
       what = "xportr_type(metacore = )",
       with = "xportr_type(metadata = )"
     )
-    metadata <- metacore
   }
+
+  ## Common section to detect default arguments
+
+  domain <- domain %||% attr(.df, "_xportr.df_arg_")
+  if (!is.null(domain)) attr(.df, "_xportr.df_arg_") <- domain
+
+  metadata <- metadata %||% attr(.df, "_xportr.df_metadata_")
+
+  # Verbose should use an explicit verbose option first, then the value set in
+  # metadata, and finally fall back to the option value
+  verbose <- verbose %||%
+    attr(.df, "_xportr.df_verbose_") %||%
+    getOption("xportr.type_verbose", "none")
+
+  ## End of common section
+
+  assert_data_frame(.df)
+  assert_string(domain, null.ok = TRUE)
+  assert_metadata(metadata)
+  assert_choice(verbose, choices = .internal_verbose_choices)
+
   # Name of the columns for working with metadata
   domain_name <- getOption("xportr.domain_name")
   variable_name <- getOption("xportr.variable_name")
   type_name <- getOption("xportr.type_name")
-  characterTypes <- c(getOption("xportr.character_types"), "_character")
-  numericTypes <- c(getOption("xportr.numeric_types"), "_numeric")
-  format_name <- getOption("xportr.format_name")
+  character_types <- c(getOption("xportr.character_types"), "_character")
+  character_metadata_types <- c(getOption("xportr.character_metadata_types"), "_character")
+  numeric_metadata_types <- c(getOption("xportr.numeric_metadata_types"), "_numeric")
+  numeric_types <- c(getOption("xportr.numeric_types"), "_numeric")
 
-  ## Common section to detect domain from argument or pipes
+  if (inherits(metadata, "Metacore")) metadata <- metadata$var_spec
 
-  df_arg <- tryCatch(as_name(enexpr(.df)), error = function(err) NULL)
-  domain <- get_domain(.df, df_arg, domain)
-  if (!is.null(domain)) attr(.df, "_xportr.df_arg_") <- domain
-
-  ## End of common section
-
-  ## Pull out correct metadata
-  metadata <- metadata %||%
-    attr(.df, "_xportr.df_metadata_") %||%
-    rlang::abort("Metadata must be set with `metadata` or `xportr_metadata()`")
-
-  if (inherits(metadata, "Metacore")) {
-    metadata <- metadata$var_spec
-  }
-
-  if (domain_name %in% names(metadata)) {
+  if (domain_name %in% names(metadata) && !is.null(domain)) {
     metadata <- metadata %>%
-      filter(!!sym(domain_name) == domain)
+      filter(!!sym(domain_name) == .env$domain)
   }
 
   metacore <- metadata %>%
-    select(!!sym(variable_name), !!sym(type_name), !!sym(format_name))
+    select(!!sym(variable_name), !!sym(type_name))
 
   # Common check for multiple variables name
   check_multiple_var_specs(metadata, variable_name)
@@ -137,15 +134,15 @@ xportr_type <- function(.df,
     mutate(
       # _character is used here as a mask of character, in case someone doesn't
       # want 'character' coerced to character
-      type.x = if_else(type.x %in% characterTypes, "_character", type.x),
-      type.x = if_else(type.x %in% numericTypes | (grepl("DT$|DTM$|TM$", variable) & !is.na(format)),
+      type.x = if_else(type.x %in% character_types, "_character", type.x),
+      type.x = if_else(type.x %in% numeric_types,
         "_numeric",
         type.x
       ),
       type.y = if_else(is.na(type.y), type.x, type.y),
       type.y = tolower(type.y),
-      type.y = if_else(type.y %in% characterTypes | (grepl("DTC$", variable) & is.na(format)), "_character", type.y),
-      type.y = if_else(type.y %in% numericTypes, "_numeric", type.y)
+      type.y = if_else(type.y %in% character_metadata_types, "_character", type.y),
+      type.y = if_else(type.y %in% numeric_metadata_types, "_numeric", type.y)
     )
 
   # It is possible that a variable exists in the table that isn't in the metadata
@@ -156,19 +153,20 @@ xportr_type <- function(.df,
   type_log(meta_ordered, type_mismatch_ind, verbose)
 
   # Check if variable types match
-  is_correct <- sapply(meta_ordered[["type.x"]] == meta_ordered[["type.y"]], isTRUE)
+  is_correct <- vapply(meta_ordered[["type.x"]] == meta_ordered[["type.y"]], isTRUE, logical(1))
   # Use the original variable iff metadata is missing that variable
   correct_type <- ifelse(is.na(meta_ordered[["type.y"]]), meta_ordered[["type.x"]], meta_ordered[["type.y"]])
 
   # Walk along the columns and coerce the variables. Modifying the columns
   # Directly instead of something like map_dfc to preserve any attributes.
-  walk2(
-    correct_type, seq_along(correct_type),
+  iwalk(
+    correct_type,
     function(x, i, is_correct) {
       if (!is_correct[i]) {
         orig_attributes <- attributes(.df[[i]])
         orig_attributes$class <- NULL
-        if (correct_type[i] %in% characterTypes) {
+        orig_attributes$levels <- NULL
+        if (correct_type[i] %in% character_types) {
           .df[[i]] <<- as.character(.df[[i]])
         } else {
           .df[[i]] <<- as.numeric(.df[[i]])
