@@ -12,7 +12,9 @@ df <- data.frame(
   Param = c("param1", "param2", "param3")
 )
 
-test_that("xportr_type: NAs are handled as expected", {
+# xportr_type ----
+## Test 1: xportr_type: NAs are handled as expected ----
+test_that("type Test 1: xportr_type: NAs are handled as expected", {
   # Namely that "" isn't converted to NA or vice versa
   # Numeric columns will become NA but that is the nature of as.numeric
   df <- data.frame(
@@ -29,7 +31,7 @@ test_that("xportr_type: NAs are handled as expected", {
   )
 
   df2 <- suppressMessages(
-    xportr_type(df, meta_example)
+    xportr_type(df, meta_example, domain = "df")
   )
 
   expect_equal(
@@ -48,11 +50,12 @@ test_that("xportr_type: NAs are handled as expected", {
   )
 })
 
-test_that("xportr_type: Variable types are coerced as expected and can raise messages", {
+## Test 2: xportr_type: Variable types are coerced as expected and can raise messages ----
+test_that("type Test 2: Variable types are coerced as expected and can raise messages", {
   # Remove empty lines in cli theme
   local_cli_theme()
 
-  (df2 <- xportr_type(df, meta_example)) %>%
+  (df2 <- xportr_type(df, meta_example, domain = "df")) %>%
     expect_message("Variable type mismatches found.") %>%
     expect_message("[0-9+] variables coerced")
 
@@ -61,9 +64,9 @@ test_that("xportr_type: Variable types are coerced as expected and can raise mes
     Val = "numeric", Param = "character"
   ))
 
-  expect_error(xportr_type(df, meta_example, verbose = "stop"))
+  expect_error(xportr_type(df, meta_example, verbose = "stop", domain = "df"))
 
-  (df3 <- suppressMessages(xportr_type(df, meta_example, verbose = "warn"))) %>%
+  (df3 <- suppressMessages(xportr_type(df, meta_example, verbose = "warn", domain = "df"))) %>%
     expect_warning()
 
   expect_equal(purrr::map_chr(df3, class), c(
@@ -73,7 +76,7 @@ test_that("xportr_type: Variable types are coerced as expected and can raise mes
 
   # Ignore other messages
   suppressMessages(
-    (df4 <- xportr_type(df, meta_example, verbose = "message")) %>%
+    (df4 <- xportr_type(df, meta_example, verbose = "message", domain = "df")) %>%
       expect_message("Variable type\\(s\\) in dataframe don't match metadata")
   )
 
@@ -83,52 +86,8 @@ test_that("xportr_type: Variable types are coerced as expected and can raise mes
   ))
 })
 
-test_that("xportr_metadata: Var types coerced as expected and raise messages", {
-  # Remove empty lines in cli theme
-  local_cli_theme()
-
-  (
-    df2 <- xportr_metadata(df, meta_example) %>%
-      xportr_type()
-  ) %>%
-    expect_message("Variable type mismatches found.") %>%
-    expect_message("[0-9+] variables coerced")
-
-  expect_equal(purrr::map_chr(df2, class), c(
-    Subj = "numeric", Different = "character",
-    Val = "numeric", Param = "character"
-  ))
-
-  suppressMessages(
-    xportr_metadata(df, meta_example) %>% xportr_type(verbose = "stop")
-  ) %>%
-    expect_error()
-
-  suppressMessages(
-    df3 <- xportr_metadata(df, meta_example) %>% xportr_type(verbose = "warn")
-  ) %>%
-    expect_warning()
-
-  expect_equal(purrr::map_chr(df3, class), c(
-    Subj = "numeric", Different = "character",
-    Val = "numeric", Param = "character"
-  ))
-
-  suppressMessages({
-    (
-      df4 <- xportr_metadata(df, meta_example) %>%
-        xportr_type(verbose = "message")
-    ) %>%
-      expect_message("Variable type\\(s\\) in dataframe don't match metadata: `Subj` and `Val`")
-  })
-
-  expect_equal(purrr::map_chr(df4, class), c(
-    Subj = "numeric", Different = "character",
-    Val = "numeric", Param = "character"
-  ))
-})
-
-test_that("xportr_type: Variables retain column attributes, besides class", {
+## Test 3: xportr_type: Variables retain column attributes, besides class ----
+test_that("type Test 3: Variables retain column attributes, besides class", {
   adsl <- dplyr::tibble(
     USUBJID = c(1001, 1002, 1003),
     SITEID = c(001, 002, 003),
@@ -152,15 +111,19 @@ test_that("xportr_type: Variables retain column attributes, besides class", {
   # Divert all messages to tempfile, instead of printing them
   #  note: be aware as this should only be used in tests that don't track
   #        messages
-  withr::local_message_sink(tempfile())
+  if (requireNamespace("withr", quietly = TRUE)) {
+    withr::local_message_sink(withr::local_tempfile())
+  }
 
   df_type_label <- adsl %>%
+    xportr_metadata(domain = "adsl") %>%
     xportr_type(metadata) %>%
     xportr_label(metadata) %>%
     xportr_length(metadata) %>%
     xportr_format(metadata)
 
   df_label_type <- adsl %>%
+    xportr_metadata(domain = "adsl") %>%
     xportr_label(metadata) %>%
     xportr_length(metadata) %>%
     xportr_format(metadata) %>%
@@ -169,7 +132,8 @@ test_that("xportr_type: Variables retain column attributes, besides class", {
   expect_equal(df_type_label, df_label_type)
 })
 
-test_that("xportr_type: expect error when domain is not a character", {
+## Test 4: xportr_type: expect error when domain is not a character ----
+test_that("type Test 4: expect error when domain is not a character", {
   df <- data.frame(x = 1, y = 2)
   df_meta <- data.frame(
     variable = c("x", "y"),
@@ -183,7 +147,8 @@ test_that("xportr_type: expect error when domain is not a character", {
   expect_error(xportr_type(df, df_meta, domain = NA))
 })
 
-test_that("xportr_type: works fine from metacore spec", {
+## Test 5: xportr_type: works fine from metacore spec ----
+test_that("type Test 5: xportr_type: works fine from metacore spec", {
   skip_if_not_installed("metacore")
 
   df <- data.frame(x = 1, y = 2)
@@ -200,19 +165,23 @@ test_that("xportr_type: works fine from metacore spec", {
     )
   ))
   processed_df <- suppressMessages(
-    xportr_type(df, metacore_meta)
+    xportr_type(df, metacore_meta, domain = "df")
   )
   expect_equal(processed_df$x, "1")
 })
 
-test_that("xportr_type: error when metadata is not set", {
+## Test 6: xportr_type: error when metadata is not set ----
+test_that("type Test 6: error when metadata is not set", {
   expect_error(
     xportr_type(df),
-    regexp = "Metadata must be set with `metadata` or `xportr_metadata\\(\\)`"
+    regexp = "Must be of type 'data.frame', 'Metacore' or set via 'xportr_metadata\\(\\)'"
   )
 })
 
-test_that("xportr_type: date variables are not converted to numeric", {
+## Test 7: xportr_type: date variables are not converted to numeric ----
+test_that("type Test 7: xportr_type: date variables are not converted to numeric", {
+  skip_if_not_installed("metacore")
+
   df <- data.frame(RFICDT = as.Date("2017-03-30"), RFICDTM = as.POSIXct("2017-03-30"))
   metacore_meta <- suppressWarnings(
     metacore::metacore(
@@ -228,7 +197,7 @@ test_that("xportr_type: date variables are not converted to numeric", {
   )
   expect_message(
     {
-      processed_df <- xportr_type(df, metacore_meta)
+      processed_df <- xportr_type(df, metacore_meta, domain = "df")
     },
     NA
   )
@@ -262,7 +231,7 @@ test_that("xportr_type: date variables are not converted to numeric", {
   adsl_original$RFICDTM <- as.POSIXct(adsl_original$RFICDTM)
 
   expect_message(
-    adsl_xpt2 <- adsl_original %>% xportr_type(metadata),
+    adsl_xpt2 <- adsl_original %>% xportr_type(metadata, domain = "adsl_original"),
     NA
   )
 
@@ -271,7 +240,8 @@ test_that("xportr_type: date variables are not converted to numeric", {
   expect_equal(adsl_original, adsl_xpt2)
 })
 
-test_that("xportr_type: Gets warning when metadata has multiple rows with same variable", {
+## Test 8: xportr_type: Gets warning when metadata has multiple rows with same variable ----
+test_that("type Test 8: Gets warning when metadata has multiple rows with same variable", {
   # This test uses the (2) functions below to reduce code duplication
   # All `expect_*` are being called inside the functions
   #
@@ -280,3 +250,78 @@ test_that("xportr_type: Gets warning when metadata has multiple rows with same v
   # Checks that message doesn't appear when xportr.domain_name is valid
   multiple_vars_in_spec_helper2(xportr_type)
 })
+
+## Test 9: xportr_type: Drops factor levels ----
+test_that("type Test 9: xportr_type: Drops factor levels", {
+  metadata <- data.frame(
+    dataset = "test",
+    variable = c("Subj", "Param", "Val", "NotUsed"),
+    type = c("numeric", "character", "numeric", "character"),
+    format = NA
+  )
+
+  .df <- data.frame(
+    Subj = as.character(123, 456, 789),
+    Different = c("a", "b", "c"),
+    Val = factor(c("1", "2", "3")),
+    Param = c("param1", "param2", "param3")
+  )
+
+  df2 <- xportr_type(.df, metadata, "test")
+
+  expect_null(attributes(df2$Val))
+})
+
+df <- data.frame(
+  STUDYID = c("PILOT01", "PILOT01", "PILOT01"),
+  USUBJID = c("01-1130", "01-1133", "01-1133"),
+  TRTEDT = c("2014-08-16", "2013-04-28", "2013-01-12")
+) %>%
+  mutate(
+    TRTEDT = as.Date(TRTEDT),
+    EXSTDTC = TRTEDT
+  )
+
+metadata <- data.frame(
+  dataset = c("df", "df", "df", "df"),
+  variable = c("STUDYID", "USUBJID", "TRTEDT", "EXSTDTC"),
+  type = c("character", "character", "numeric", "date"),
+  format = c(NA, NA, "DATE9.", NA)
+)
+
+# xportr_metadata ----
+## Test 10: xportr_metadata: Var date types (--DTC) coerced as expected and raise messages ----
+test_that("type Test 10: Var date types (--DTC) coerced as expected and raise messages", {
+  # Remove empty lines in cli theme
+  local_cli_theme()
+
+  (
+    df2 <- xportr_metadata(df, metadata) %>%
+      xportr_type()
+  ) %>%
+    expect_message("Variable type mismatches found.") %>%
+    expect_message("[0-9+] variables coerced")
+
+  expect_equal(purrr::map_chr(df2, class), c(
+    STUDYID = "character", USUBJID = "character",
+    TRTEDT = "Date", EXSTDTC = "character"
+  ))
+})
+
+# xportr_type ----
+## Test 11: xportr_type: Works as expected with only one domain in metadata ----
+test_that("type Test 11: Works as expected with only one domain in metadata", {
+  adsl <- data.frame(
+    USUBJID = c(1001, 1002, 1003),
+    BRTHDT = c(1, 1, 2)
+  )
+
+  metadata <- data.frame(
+    dataset = c("adsl", "adsl"),
+    variable = c("USUBJID", "BRTHDT"),
+    type = c("numeric", "numeric"),
+    format = c(NA, "DATE9.")
+  )
+
+  expect_equal(xportr_type(adsl, metadata), adsl)
+})
