@@ -8,8 +8,8 @@ data_to_save <- function() {
 test_large_files <- Sys.getenv("XPORTR.TEST_LARGE_FILES", FALSE)
 
 # xportr_write ----
-## Test 1: xportr_write: exported data can be saved to a file ----
-test_that("write Test 1: exported data can be saved to a file", {
+## Test 1: exported data can be saved to a file ----
+test_that("xportr_write Test 1: exported data can be saved to a file", {
   skip_if_not_installed("withr")
   tmp <- withr::local_file("xyz.xpt")
   local_data <- data_to_save()
@@ -18,8 +18,8 @@ test_that("write Test 1: exported data can be saved to a file", {
   expect_equal(read_xpt(tmp), local_data)
 })
 
-## Test 2: xportr_write: exported data can still be saved to a file with a label ----
-test_that("write Test 2: exported data can still be saved to a file with a label", {
+## Test 2: exported data can still be saved to a file with a label ----
+test_that("xportr_write Test 2: exported data can still be saved to a file with a label", {
   skip_if_not_installed("withr")
   tmp <- withr::local_file("xyz.xpt")
 
@@ -33,8 +33,8 @@ test_that("write Test 2: exported data can still be saved to a file with a label
   expect_output(str(read_xpt(tmp)), "Lorem ipsum dolor sit amet")
 })
 
-## Test 3: xportr_write: exported data can be saved to a file with a metadata ----
-test_that("write Test 3: exported data can be saved to a file with a metadata", {
+## Test 3: exported data can be saved to a file with a metadata ----
+test_that("xportr_write Test 3: exported data can be saved to a file with a metadata", {
   skip_if_not_installed("withr")
   tmp <- withr::local_file("xyz.xpt")
 
@@ -50,8 +50,8 @@ test_that("write Test 3: exported data can be saved to a file with a metadata",
   expect_output(str(read_xpt(tmp)), "Lorem ipsum dolor sit amet")
 })
 
-## Test 4: xportr_write: exported data can be saved to a file with a existing metadata ----
-test_that("write Test 4: exported data can be saved to a file with a existing metadata", {
+## Test 4: exported data can be saved to a file with a existing metadata ----
+test_that("xportr_write Test 4: exported data can be saved to a file with a existing metadata", {
   skip_if_not_installed("withr")
   tmp <- withr::local_file("xyz.xpt")
 
@@ -68,8 +68,8 @@ test_that("write Test 4: exported data can be saved to a file with a existing me
   expect_output(str(read_xpt(tmp)), "Lorem ipsum dolor sit amet")
 })
 
-## Test 5: xportr_write: expect error when invalid multibyte string is passed in label ----
-test_that("write Test 5: expect error when invalid multibyte string is passed in label", {
+## Test 5: expect error when invalid multibyte string is passed in label ----
+test_that("xportr_write Test 5: expect error when invalid multibyte string is passed in label", {
   skip_if_not_installed("withr")
   expect_error(
     xportr_write(
@@ -83,8 +83,8 @@ test_that("write Test 5: expect error when invalid multibyte string is passed in
   )
 })
 
-## Test 6: xportr_write: expect error when file name is over 8 characters long ----
-test_that("write Test 6: expect error when file name is over 8 characters long", {
+## Test 6: expect error when file name is over 8 characters long ----
+test_that("xportr_write Test 6: expect error when file name is over 8 characters long", {
   skip_if_not_installed("withr")
   expect_error(
     xportr_write(
@@ -95,8 +95,8 @@ test_that("write Test 6: expect error when file name is over 8 characters long",
   )
 })
 
-## Test 7: xportr_write: expect error when file name contains non-ASCII symbols or special characters ----
-test_that("write Test 7: expect error when file name contains non-ASCII symbols or special characters", {
+## Test 7: expect error when file name contains non-ASCII symbols or special characters ----
+test_that("xportr_write Test 7: expect error when file name contains non-ASCII symbols or special characters", {
   skip_if_not_installed("withr")
   expect_error(
     xportr_write(data_to_save(), withr::local_file("<test>.xpt"), strict_checks = TRUE),
@@ -104,8 +104,8 @@ test_that("write Test 7: expect error when file name contains non-ASCII symbols
   )
 })
 
-## Test 8: xportr_write: expect warning when file name contains underscore and strict_checks = FALSE ----
-test_that("write Test 8: expect warning when file name contains underscore and strict_checks = FALSE", {
+## Test 8: expect warning when file name contains underscore and strict_checks = FALSE ----
+test_that("xportr_write Test 8: expect warning when file name contains underscore and strict_checks = FALSE", {
   skip_if_not_installed("withr")
   expect_warning(
     xportr_write(data_to_save(), withr::local_file("test_.xpt"), strict_checks = FALSE),
@@ -113,8 +113,8 @@ test_that("write Test 8: expect warning when file name contains underscore and s
   )
 })
 
-## Test 9: xportr_write: expect error when label contains non-ASCII symbols or special characters ----
-test_that("write Test 9: expect error when label contains non-ASCII symbols or special characters", {
+## Test 9: expect error when label contains non-ASCII symbols or special characters ----
+test_that("xportr_write Test 9: expect error when label contains non-ASCII symbols or special characters", {
   skip_if_not_installed("withr")
   expect_error(
     xportr_write(
@@ -130,8 +130,8 @@ test_that("write Test 9: expect error when label contains non-ASCII symbols or s
   )
 })
 
-## Test 10: xportr_write: expect error when label is over 40 characters ----
-test_that("write Test 10: expect error when label is over 40 characters", {
+## Test 10: expect error when label is over 40 characters ----
+test_that("xportr_write Test 10: expect error when label is over 40 characters", {
   skip_if_not_installed("withr")
   expect_error(
     xportr_write(
@@ -147,8 +147,8 @@ test_that("write Test 10: expect error when label is over 40 characters", {
   )
 })
 
-## Test 11: xportr_write: expect error when an xpt validation fails with strict_checks set to TRUE ----
-test_that("write Test 11: expect error when an xpt validation fails with strict_checks set to TRUE", {
+## Test 11: expect error when an xpt validation fails with strict_checks set to TRUE ----
+test_that("xportr_write Test 11: expect error when an xpt validation fails with strict_checks set to TRUE", {
   skip_if_not_installed("withr")
   local_data <- data_to_save()
   attr(local_data$X, "format.sas") <- "foo"
@@ -168,8 +168,8 @@ test_that("write Test 11: expect error when an xpt validation fails with strict_
   )
 })
 
-## Test 12: xportr_write: expect warning when an xpt validation fails with strict_checks set to FALSE ----
-test_that("write Test 12: expect warning when an xpt validation fails with strict_checks set to FALSE", {
+## Test 12: expect warning when an xpt validation fails with strict_checks set to FALSE ----
+test_that("xportr_write Test 12: expect warning when an xpt validation fails with strict_checks set to FALSE", {
   skip_if_not_installed("withr")
   local_data <- data_to_save()
   attr(local_data$X, "format.sas") <- "foo"
@@ -189,8 +189,8 @@ test_that("write Test 12: expect warning when an xpt validation fails with stric
   )
 })
 
-## Test 13: xportr_write: Capture errors by haven and report them as such ----
-test_that("write Test 13: Capture errors by haven and report them as such", {
+## Test 13: Capture errors by haven and report them as such ----
+test_that("xportr_write Test 13: Capture errors by haven and report them as such", {
   skip_if_not_installed("withr")
   local_data <- data_to_save()
   attr(local_data$X, "format.sas") <- "E8601LXw.asdf"
@@ -212,8 +212,98 @@ test_that("write Test 13: Capture errors by haven and report them as such", {
   )
 })
 
-## Test 14: xportr_write: `split_by` attribute is used to split the data ----
-test_that("write Test 14: `split_by` attribute is used to split the data", {
+## Test 14: if file size is less than `max_size_gb`, export only one file ----
+test_that("xportr_write Test 14: if file size is less than `max_size_gb`, export only one file", {
+  adlb <- pharmaverseadam::adlb
+
+  tmpdir <- tempdir()
+
+  # 5 GB
+  max_size_gb <- 5
+
+  expect_message(
+    xportr_write(adlb,
+      path = paste0(tmpdir, "/adlb.xpt"),
+      domain = "adlb",
+      max_size_gb = max_size_gb,
+      strict_checks = FALSE
+    ),
+    "Data frame exported to 1 xpt files."
+  )
+
+  expect_true(
+    file.exists(file.path(tmpdir, "adlb.xpt")),
+    file.info(file.path(tmpdir, "adlb.xpt"))$size <= as.numeric(format(max_size_gb * 10^9, scientific = FALSE))
+  )
+})
+
+## Test 15: `max_size_gb` is used to split data frame into specified maximum file size ----
+test_that("xportr_write Test 15: `max_size_gb` is used to split data frame into specified maximum file size", {
+  adlb <- pharmaverseadam::adlb
+
+  tmpdir <- tempdir()
+
+  # 20 mb
+  max_size_gb <- 20 / 1000
+
+  expect_message(
+    xportr_write(adlb,
+      path = paste0(tmpdir, "/adlb.xpt"),
+      domain = "adlb",
+      max_size_gb = max_size_gb,
+      strict_checks = FALSE
+    ),
+    "Data frame exported to 5 xpt files."
+  )
+
+  expect_true(
+    file.exists(file.path(tmpdir, "adlb1.xpt")),
+    file.info(file.path(tmpdir, "adlb1.xpt"))$size <= as.numeric(format(max_size_gb * 10^9, scientific = FALSE))
+  )
+
+  expect_true(
+    file.exists(file.path(tmpdir, "adlb2.xpt")),
+    file.info(file.path(tmpdir, "adlb2.xpt"))$size <= as.numeric(format(max_size_gb * 10^9, scientific = FALSE))
+  )
+
+  expect_true(
+    file.exists(file.path(tmpdir, "adlb3.xpt")),
+    file.info(file.path(tmpdir, "adlb3.xpt"))$size <= as.numeric(format(max_size_gb * 10^9, scientific = FALSE))
+  )
+
+  expect_true(
+    file.exists(file.path(tmpdir, "adlb4.xpt")),
+    file.info(file.path(tmpdir, "adlb4.xpt"))$size <= as.numeric(format(max_size_gb * 10^9, scientific = FALSE))
+  )
+
+  expect_true(
+    file.exists(file.path(tmpdir, "adlb5.xpt")),
+    file.info(file.path(tmpdir, "adlb5.xpt"))$size <= as.numeric(format(max_size_gb * 10^9, scientific = FALSE))
+  )
+})
+
+
+## Test 16: Large file sizes are reported and warned ----
+test_that("xportr_write Test 16: Large file sizes are reported and warned", {
+  skip_if_not(test_large_files)
+  tmpdir <- tempdir()
+  tmp <- file.path(tmpdir, "xyz.xpt")
+
+  on.exit(unlink(tmpdir))
+
+  # Large_df should be at least 5GB
+  large_df <- do.call(
+    data.frame, replicate(80000, rep("large", 80000), simplify = FALSE)
+  )
+
+  expect_warning(
+    xportr_write(large_df, path = tmp),
+    class = "xportr.xpt_size"
+  )
+})
+
+## Test 17: `split_by` attribute is used to split the data ----
+test_that("xportr_write Test 17: `split_by` attribute is used to split the data", {
   tmpdir <- tempdir()
   tmp <- file.path(tmpdir, "xyz.xpt")
 
@@ -233,6 +323,7 @@ test_that("write Test 14: `split_by` attribute is used to split the data", {
   expect_true(
     file.exists(file.path(tmpdir, "xyz3.xpt"))
   )
+
   expect_equal(
     read_xpt(file.path(tmpdir, "xyz1.xpt")) %>%
       extract2("X") %>%
@@ -255,22 +346,3 @@ test_that("write Test 14: `split_by` attribute is used to split the data", {
     1
   )
 })
-
-## Test 15: xportr_write: Large file sizes are reported and warned ----
-test_that("write Test 15: Large file sizes are reported and warned", {
-  skip_if_not(test_large_files)
-  tmpdir <- tempdir()
-  tmp <- file.path(tmpdir, "xyz.xpt")
-
-  on.exit(unlink(tmpdir))
-
-  # Large_df should be at least 5GB
-  large_df <- do.call(
-    data.frame, replicate(80000, rep("large", 80000), simplify = FALSE)
-  )
-
-  expect_warning(
-    xportr_write(large_df, path = tmp),
-    class = "xportr.xpt_size"
-  )
-})
